Rotate — Thumbor 7.0.0a1 documentation

# Rotate

Usage: rotate(angle)

## Description

This filter rotates the given image according to the angle value passed.

Note

This filter rotates the image according to the engine. For the PIL engine the rotation is done counter-clockwise.

## Arguments

- `angle` - `0 to 359` - The euler angle to rotate the image by. Numbers greater or equal than 360 will be transformed to a equivalent angle between 0 and 359.

## Example

http://localhost:8888/unsafe/filters:rotate(90)/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg